@@ -4,9 +4,7 @@
 #'  The series of `go_to_*()` addins help you go to
 #'  common files used in developing a `{golem}` application.
 #'
-#' @importFrom rstudioapi getSourceEditorContext modifyRange
 #' @importFrom attempt stop_if_not
-#' @importFrom rstudioapi modifyRange
 #'
 #' @aliases addins
 #' @rdname addins
@@ -17,16 +15,16 @@ NULL
 #' @aliases addins
 insert_ns <- function() {
   stop_if_not(
-    rstudioapi::hasFun("getSourceEditorContext"),
+    rstudioapi_hasFun("getSourceEditorContext"),
     msg = "Your version of RStudio does not support `getSourceEditorContext`"
   )
 
   stop_if_not(
-    rstudioapi::hasFun("modifyRange"),
+    rstudioapi_hasFun("modifyRange"),
     msg = "Your version of RStudio does not support `modifyRange`"
   )
 
-  curr_editor <- rstudioapi::getSourceEditorContext()
+  curr_editor <- rstudioapi_getSourceEditorContext()
 
   id <- curr_editor$id
   sel_rng <- curr_editor$selection[[1]]$range
@@ -34,28 +32,31 @@ insert_ns <- function() {
 
   mod_text <- paste0("ns(", sel_text, ")")
 
-  rstudioapi::modifyRange(sel_rng, mod_text, id = id)
+  rstudioapi_modifyRange(
+    sel_rng,
+    mod_text,
+    id = id
+  )
 }
 
-#' @importFrom fs path file_exists
 go_to <- function(
   file,
   wd = golem::get_golem_wd()
 ) {
-  file <- path(
+  file <- fs_path(
     wd,
     file
   )
-  if (!file_exists(file)) {
+  if (!fs_file_exists(file)) {
     message(file, "not found.")
   }
 
   stop_if_not(
-    rstudioapi::hasFun("navigateToFile"),
+    rstudioapi_hasFun("navigateToFile"),
     msg = "Your version of RStudio does not support `navigateToFile`"
   )
 
-  rstudioapi::navigateToFile(file)
+  rstudioapi_navigateToFile(file)
 }
 
 #' @rdname addins
