@@ -34,8 +34,8 @@ detach_all_attached <- function() {
 check_name_consistency <- function(pkg) {
   old_dir <- setwd(pkg)
 
-  package_name <- desc::desc_get("Package")
-  pth <- fs::path(
+  package_name <- desc_get(keys = "Package")
+  pth <- fs_path(
     pkg,
     "R",
     "app_config.R"
@@ -88,9 +88,6 @@ check_name_consistency <- function(pkg) {
 #' @inheritParams pkgload::load_all
 #'
 #' @param ... Other arguments passed to `pkgload::load_all()`
-#' @importFrom roxygen2 roxygenise
-#' @importFrom pkgload load_all
-#' @importFrom rstudioapi isAvailable hasFun documentSaveAll
 #' @export
 #'
 #' @return Used for side-effects
@@ -107,12 +104,17 @@ document_and_reload <- function(
   # We'll start by checking if the package name is correct
 
   check_name_consistency(pkg)
+  rlang::check_installed("pkgload")
 
-  if (rstudioapi::isAvailable() & rstudioapi::hasFun("documentSaveAll")) {
+  if (
+    rlang::is_installed("rstudioapi") &&
+      rstudioapi::isAvailable() &&
+      rstudioapi::hasFun("documentSaveAll")
+  ) {
     rstudioapi::documentSaveAll()
   }
   roxed <- try({
-    roxygenise(
+    roxygen2_roxygenise(
       package.dir = pkg,
       roclets = roclets,
       load_code = load_code,
@@ -120,14 +122,14 @@ document_and_reload <- function(
     )
   })
   if (attempt::is_try_error(roxed)) {
-    cli::cat_rule(
+    cli_cat_rule(
       "Error documenting your package"
     )
     dialog_if_has("Alert", "Error documenting your package")
     return(invisible(FALSE))
   }
   loaded <- try({
-    load_all(
+    pkgload_load_all(
       pkg,
       export_all = export_all,
       helpers = helpers,
@@ -137,7 +139,7 @@ document_and_reload <- function(
   })
 
   if (attempt::is_try_error(loaded)) {
-    cli::cat_rule(
+    cli_cat_rule(
       "Error loading your package"
     )
     dialog_if_has("Alert", "Error loading your package")
@@ -145,8 +147,15 @@ document_and_reload <- function(
   }
 }
 
-dialog_if_has <- function(title, message, url = "") {
-  if (rstudioapi::isAvailable() & rstudioapi::hasFun("showDialog")) {
+dialog_if_has <- function(
+  title,
+  message,
+  url = ""
+) {
+  if (
+    rlang::is_installed("rstudioapi") &&
+      rstudioapi::isAvailable() && rstudioapi::hasFun("showDialog")
+  ) {
     rstudioapi::showDialog(title, message, url)
   }
 }
