@@ -10,8 +10,6 @@
 #' @param recommended A vector of recommended packages.
 #' @param spellcheck Whether or not to use a spellcheck test.
 #'
-#' @importFrom usethis use_testthat use_package
-#' @importFrom fs path_abs
 #' @rdname use_recommended
 #'
 #' @export
@@ -23,15 +21,14 @@ use_recommended_deps <- function(
   recommended = c("shiny", "DT", "attempt", "glue", "htmltools", "golem")
 ) {
   .Deprecated(
-    "golem::use_recommended_deps",
-    msg <- "use_recommended_deps() is soft deprecated and will be removed in future versions of {golem}."
+    msg = "use_recommended_deps() is soft deprecated and will be removed in future versions of {golem}."
   )
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   for (i in sort(recommended)) {
-    try(use_package(i))
+    try(usethis_use_package(i))
   }
 
   cat_green_tick("Dependencies added")
@@ -40,10 +37,8 @@ use_recommended_deps <- function(
 
 #' @rdname use_recommended
 #' @export
-#' @importFrom usethis use_testthat use_package use_spell_check
 #' @importFrom utils capture.output
 #' @importFrom attempt without_warning stop_if
-#' @importFrom fs path_abs path file_exists
 use_recommended_tests <- function(
   pkg = get_golem_wd(),
   spellcheck = TRUE,
@@ -51,39 +46,37 @@ use_recommended_tests <- function(
   lang = "en-US",
   error = FALSE
 ) {
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
 
   on.exit(setwd(old))
 
-  if (!dir.exists(
-    path(path_abs(pkg), "tests")
+  if (!fs_dir_exists(
+    fs_path(fs_path_abs(pkg), "tests")
   )) {
-    without_warning(use_testthat)()
+    without_warning(usethis_use_testthat)()
   }
   if (!requireNamespace("processx")) {
     stop("Please install the {processx} package to add the recommended tests.")
   }
 
   stop_if(
-    path(old, "tests", "testthat", "test-golem-recommended.R"),
-    file_exists,
+    fs_path(old, "tests", "testthat", "test-golem-recommended.R"),
+    fs_file_exists,
     "test-golem-recommended.R already exists. \nPlease remove it first if you need to reinsert it."
   )
 
-  file_copy(
+  fs_file_copy(
     golem_sys("utils", "test-golem-recommended.R"),
-    path(old, "tests", "testthat"),
+    fs_path(old, "tests", "testthat"),
     overwrite = TRUE
   )
 
   if (spellcheck) {
-    use_spell_check(
+    usethis_use_spell_check(
       vignettes = vignettes,
       lang = lang,
       error = error
     )
   }
-
-
   cat_green_tick("Tests added")
 }
